@@ -23,8 +23,8 @@ pub(crate) fn generate_from_prototype(
     }
 
     Ok(Problem {
-        plan: generate_plan(&problem, locations, jobs_size, area_size)?,
-        fleet: generate_fleet(&problem, vehicle_types_size),
+        plan: generate_plan(problem, locations, jobs_size, area_size)?,
+        fleet: generate_fleet(problem, vehicle_types_size),
         objectives: problem.objectives.clone(),
     })
 }
